Learn R Programming

admisc (version 0.41)

change: Generic function to change the structure of an object, function of the (changed) parameters used to create it.

Description

A generic function that applies different altering methods for different types of objects (of certain classes).

Usage

change(x, ...)

Value

The changed object.

Arguments

x

An object of a particular class.

...

Arguments to be passed to a specific method.

Author

Adrian Dusa

Details

For the time being, this function is designed to change truth table objects (only). Future versions will likely add class methods for different other objects.

Examples

Run this code
if (FALSE) {
# An example to change a QCA truth table
library(QCA)

ttLF <- truthTable(LF, outcome = SURV, incl.cut = 0.8)
minimize(ttLF, include = "?")

# excluding contradictory simplifying assumptions
minimize(
    change(ttLF, exclude = findRows(type = 2)),
    include = "?"
)
}

Run the code above in your browser using DataLab